@@ -905,30 +905,48 @@ void mod_crop_h_cb(GtkWidget *widget, void *data)
 
 void force_aspect_from_w()
 {
-   int w,h,ww;
+   int dw,w,ww;
    
    w=(int)GTK_ADJUSTMENT(width_adj)->value;
-   h=(int)GTK_ADJUSTMENT(height_adj)->value;
-   
-   ww=(w*current.image->rgb_height)/current.image->rgb_width;
+   dw=w - current.image->rgb_width;
+
+   ww=(dw*current.image->rgb_height)/current.image->rgb_width + current.image->rgb_height;
+
+   correcting_aspect=1;
+#ifdef 1
+   gtk_spin_button_spin(GTK_SPIN_BUTTON(height_wid),GTK_SPIN_USER_DEFINED,(gfloat)
+			(ww-gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height_wid))));
+#else
    gtk_spin_button_spin(GTK_SPIN_BUTTON(height_wid),1,(gfloat)
 			(gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height_wid))-
 			 ww));
+#endif
+   correcting_aspect=0;
+
    gtk_widget_queue_draw(GTK_WIDGET(height_wid));
    mod_height=1;
 }
 
 void force_aspect_from_h()
 {
-   int w,h,hh;
+   int dh,h,hh;
    
-   w=(int)GTK_ADJUSTMENT(width_adj)->value;
    h=(int)GTK_ADJUSTMENT(height_adj)->value;
+   dh = h - current.image->rgb_height;
    
-   hh=(h*current.image->rgb_width)/current.image->rgb_height;
+   hh=(dh*current.image->rgb_width)/current.image->rgb_height + current.image->rgb_width; 
+
+   correcting_aspect=1;
+#ifdef 1
+   gtk_spin_button_spin(GTK_SPIN_BUTTON(width_wid),GTK_SPIN_USER_DEFINED,(gfloat)
+			(hh-gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width_wid))));
+#else
    gtk_spin_button_spin(GTK_SPIN_BUTTON(width_wid),1,(gfloat)
 			(gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width_wid))-
 			 hh));
+#endif
+   correcting_aspect=0;
+
    gtk_widget_queue_draw(GTK_WIDGET(width_wid));
    mod_width=1;
 }
@@ -940,7 +958,7 @@ void mod_width_cb(GtkWidget *widget, void *data)
 	mod_height=0;
 	return;
      }
-   if (fixed_aspect) force_aspect_from_w();
+   if (fixed_aspect && !correcting_aspect) force_aspect_from_w();
 }
 
 void mod_height_cb(GtkWidget *widget, void *data)
@@ -950,7 +968,7 @@ void mod_height_cb(GtkWidget *widget, void *data)
 	mod_width=0;
 	return;
      }
-   if (fixed_aspect) force_aspect_from_h();
+   if (fixed_aspect && !correcting_aspect) force_aspect_from_h();
 }
 
 void toggle_fixed_cb(GtkWidget *widget, void *data)
@@ -958,8 +976,8 @@ void toggle_fixed_cb(GtkWidget *widget, void *data)
    if (fixed_aspect) fixed_aspect=0;
    else
      {
-	force_aspect_from_w();
-	fixed_aspect=1;
+        force_aspect_from_w();
+        fixed_aspect=1;
      }
 }
 
@@ -1044,8 +1062,10 @@ void handle_add_to_clist(GtkWidget *widget, gpointer *data)
 
 void handle_del_from_clist(GtkWidget *widget, gpointer *data)
 {
-   del_file_from_list(current.info->file);
-   show_image_n(current.number);
+  if(current.info) {
+     del_file_from_list(current.info->file);
+     show_image_n(current.number);
+  }
 }
 
 void handle_load_clist(GtkWidget *widget, gpointer *data)
@@ -1326,9 +1346,7 @@ void init_edit()
    gtk_widget_show(button);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_previous),NULL);
    gtk_box_pack_start (GTK_BOX(vbox),button,FALSE,FALSE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'z',0);
+   gtk_accel_group_add(image_accel,'z',0,0,GTK_OBJECT(button),"clicked");
 
    pixmap=gnome_stock_pixmap_widget(window_edit,GNOME_STOCK_MENU_FORWARD);
    gtk_widget_show(pixmap);
@@ -1337,10 +1355,8 @@ void init_edit()
    gtk_widget_show(button);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_next),NULL);
    gtk_box_pack_start (GTK_BOX(vbox),button,FALSE,FALSE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 ' ',0);
-
+   gtk_accel_group_add(image_accel,' ',0,0,
+				 GTK_OBJECT(button),"clicked");
    
    
    label=gtk_label_new(_("Colors"));
@@ -1599,9 +1615,8 @@ void init_edit()
 			_("Halves the width and height of the image (CTRL-,)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_halve),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 ',',GDK_CONTROL_MASK);
+   gtk_accel_group_add(image_accel, ',', GDK_CONTROL_MASK,0,
+		       GTK_OBJECT(button),"clicked");
    
    gdk_imlib_data_to_pixmap(size_down_xpm,&pmap,&mask);
    pixmap=gtk_pixmap_new(pmap,mask);gtk_widget_show(pixmap);
@@ -1612,9 +1627,8 @@ void init_edit()
 			_("Reduces the size of the image by 10% (,)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_down),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 ',',0);
+   gtk_accel_group_add(image_accel,',',0,0,
+		       GTK_OBJECT(button),"clicked");
 
    gdk_imlib_data_to_pixmap(size_orig_xpm,&pmap,&mask);
    pixmap=gtk_pixmap_new(pmap,mask);gtk_widget_show(pixmap);
@@ -1625,9 +1639,8 @@ void init_edit()
 			_("Restores the image to its original size (n)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_original),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'n',0);
+   gtk_accel_group_add(image_accel,'n',0,0,
+		       GTK_OBJECT(button),"clicked");
 
    gdk_imlib_data_to_pixmap(size_up_xpm,&pmap,&mask);
    pixmap=gtk_pixmap_new(pmap,mask);gtk_widget_show(pixmap);
@@ -1638,9 +1651,8 @@ void init_edit()
 			_("Increases the image size by 10% (.)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_up),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 '.',0);
+   gtk_accel_group_add(image_accel,'.',0,0,
+		       GTK_OBJECT(button),"clicked");
 
    gdk_imlib_data_to_pixmap(size_double_xpm,&pmap,&mask);
    pixmap=gtk_pixmap_new(pmap,mask);gtk_widget_show(pixmap);
@@ -1651,9 +1663,8 @@ void init_edit()
 			_("Doubles the width and height of the image (CTRL-.)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_double),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 '.',GDK_CONTROL_MASK);
+   gtk_accel_group_add(image_accel, '.', GDK_CONTROL_MASK, 0,
+		       GTK_OBJECT(button),"clicked");
 
    hbox2=gtk_hbox_new(TRUE,0);
    gtk_widget_show(hbox2);
@@ -1668,9 +1679,9 @@ void init_edit()
 			_("Expands the image to fit the screen whilst retaining its current aspect ratio (f)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_fit),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'f',0);
+   gtk_accel_group_add(image_accel,'f',0,0,
+		       GTK_OBJECT(button),"clicked");
+		       
 
    gdk_imlib_data_to_pixmap(size_max_xpm,&pmap,&mask);
    pixmap=gtk_pixmap_new(pmap,mask);gtk_widget_show(pixmap);
@@ -1681,9 +1692,9 @@ void init_edit()
 			_("Expands the image to fill the entire screen (m)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(handle_image_resize_maximize),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'm',0);
+   gtk_accel_group_add(image_accel,'m',0,0,
+		       GTK_OBJECT(button),"clicked");
+		       
 
    frame=gtk_aspect_frame_new(_("Geometry"),0.5,0.5,0.0,TRUE);
    gtk_widget_show(frame);
@@ -1714,9 +1725,9 @@ void init_edit()
 			_("Flips the image horizontally (h)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(image_fliph),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'h',0);
+   gtk_accel_group_add(image_accel, 'h', 0, 0,
+		       GTK_OBJECT(button),"clicked");
+			
 
    gdk_imlib_data_to_pixmap(geom_flipv_xpm,&pmap,&mask);
    pixmap=gtk_pixmap_new(pmap,mask);gtk_widget_show(pixmap);
@@ -1727,9 +1738,9 @@ void init_edit()
 			_("Flips the image vertically (v)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(image_flipv),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'v',0);
+   gtk_accel_group_add(image_accel, 'v',0, 0,
+		       GTK_OBJECT(button),"clicked");
+		       
 
    hbox2=gtk_hbox_new(FALSE,0);
    gtk_widget_show(hbox2);
@@ -1744,9 +1755,9 @@ void init_edit()
 			_("Flips the image around the x=y diagonal (r)"),NULL);
    gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(image_rotate),NULL);
    gtk_box_pack_start(GTK_BOX(hbox2),button,TRUE,TRUE,0);
-   gtk_accelerator_table_install(image_accel,
-				 GTK_OBJECT(button),"clicked",
-				 'r',0);
+   gtk_accel_group_add(image_accel, 'r',0,0,
+		       GTK_OBJECT(button),"clicked");
+			
    
    frame=gtk_aspect_frame_new(_("Cropping"),0.5,0.5,0.0,TRUE);
    gtk_widget_show(frame);
