@@ -171,8 +171,15 @@ extern GtkWidget              *blue_view;
 extern GtkObject              *adjusters[12];
 extern GtkWidget              *sliders[12];
 extern char                   autoapply;
+#ifdef GTK_HAVE_FEATURES_1_1_0
+extern GtkAccelGroup          *image_accel;
+extern GtkAccelGroup          *edit_accel;
+#else
 extern GtkAcceleratorTable    *image_accel;
 extern GtkAcceleratorTable    *edit_accel;
+#define gtk_accel_group_add(at,key,mods,dummy,widget,signal) \
+         (gtk_accelerator_table_install(at,widget,signal,key,mods))
+#endif
 extern GtkWidget              *tips;
 extern GtkWidget              *list;
 extern char                   mods_changed;
@@ -182,6 +189,7 @@ extern guint32                silde_speed;
 extern int                    num_categories;
 extern char                   **categories;
 extern char                   fixed_aspect;
+extern char                   correcting_aspect;
 extern GtkObject              *width_adj,*height_adj;
 extern GtkWidget              *width_wid,*height_wid;
 extern GtkObject              *cropx_adj,*cropy_adj,*cropw_adj,*croph_adj;
