@@ -58,6 +58,10 @@ int isdir(char *s)
    return 0;
 }
 
+int ls_compare_func(const void *a, const void *b) {
+  return strcmp(*(char **)a, *(char **)b);
+}
+
 char **ls(char *dir, int *num)
 {
    int i,dirlen;
@@ -101,6 +105,7 @@ char **ls(char *dir, int *num)
    if (i<dirlen) dirlen=i;     /* dir got shorter... */
    closedir(dirp);
    *num = dirlen;
+   qsort(names, dirlen, sizeof(char *), ls_compare_func);
    return names;
 }
 
