@@ -6,66 +6,55 @@
 #include "ee.h"
 #include "stdimg.xpm"
 
+static GnomeUIInfo menu6[]=
+{
+  GNOMEUIINFO_ITEM_STOCK(N_("About"), N_("Info about this program"), about_image_cb, GNOME_STOCK_MENU_ABOUT),
+  GNOMEUIINFO_SEPARATOR,
+  GNOMEUIINFO_HELP("ee"),
+  GNOMEUIINFO_END
+};
+
 static GnomeUIInfo menu5[]= 
 {
-   GNOMEUIINFO_ITEM(N_("Original size"),N_("Scale this image to it's original size"),handle_image_resize_original,NULL),
-   GNOMEUIINFO_ITEM(N_("Fit to screen"),N_("Scale this image to the size of the screen keeping its current aspect"),handle_image_resize_fit,NULL),
-   GNOMEUIINFO_ITEM(N_("Maximize size"),N_("Scale this image to be the full size of the screen"),handle_image_resize_maximize,NULL),
+   GNOMEUIINFO_ITEM_NONE(N_("Original size"),N_("Scale this image to it's original size"),handle_image_resize_original),
+   GNOMEUIINFO_ITEM_NONE(N_("Fit to screen"),N_("Scale this image to the size of the screen keeping its current aspect"),handle_image_resize_fit),
+   GNOMEUIINFO_ITEM_NONE(N_("Maximize size"),N_("Scale this image to be the full size of the screen"),handle_image_resize_maximize),
    GNOMEUIINFO_SEPARATOR,
-   GNOMEUIINFO_ITEM(N_("Double size"),N_("Double the size of this image"),handle_image_resize_double,NULL),
-   GNOMEUIINFO_ITEM(N_("Halve size"),N_("Halve the size of this image"),handle_image_resize_halve,NULL),
-   GNOMEUIINFO_ITEM(N_("+10% size"),N_("Increase image size by 10%"),handle_image_resize_up,NULL),
-   GNOMEUIINFO_ITEM(N_("-10% size"),N_("Decrease image size by 10%"),handle_image_resize_down,NULL),
+   GNOMEUIINFO_ITEM_NONE(N_("Double size"),N_("Double the size of this image"),handle_image_resize_double),
+   GNOMEUIINFO_ITEM_NONE(N_("Halve size"),N_("Halve the size of this image"),handle_image_resize_halve),
+   GNOMEUIINFO_ITEM_NONE(N_("+10% size"),N_("Increase image size by 10%"),handle_image_resize_up),
+   GNOMEUIINFO_ITEM_NONE(N_("-10% size"),N_("Decrease image size by 10%"),handle_image_resize_down),
    GNOMEUIINFO_SEPARATOR,
-   GNOMEUIINFO_ITEM(N_("Set as desktop background"),N_("Put this image in the desktop background in a tiled fashion"),handle_image_set_desktop,NULL),
+   GNOMEUIINFO_ITEM_NONE(N_("Set as desktop background"),N_("Put this image in the desktop background in a tiled fashion"),handle_image_set_desktop),
    GNOMEUIINFO_END
 };
 
 static GnomeUIInfo menu4[]= 
 {
-   GNOMEUIINFO_ITEM(N_("Show/Hide Edit Window"),N_("Display the Editor Window"),start_edit_cb, NULL),
-   GNOMEUIINFO_ITEM(N_("Show/Hide Thumbnail Window"),N_("Display the Thumbnail Window"),showthumbs, NULL),
+   GNOMEUIINFO_ITEM_NONE(N_("Show/Hide Edit Window"),N_("Display the Editor Window"),start_edit_cb),
+   GNOMEUIINFO_ITEM_NONE(N_("Show/Hide Thumbnail Window"),N_("Display the Thumbnail Window"),showthumbs),
    GNOMEUIINFO_END
 };
 
 static GnomeUIInfo menu3[]= 
 {
-     { GNOME_APP_UI_ITEM,N_("Open"),N_("Open up a new image file and add it to the image list"),image_open,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN,
-	0,0,NULL
-     },
-     { GNOME_APP_UI_ITEM,N_("Save"),N_("Save this image"),image_save,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
-	0,0,NULL
-     },
-     { GNOME_APP_UI_ITEM,N_("Save As"),N_("Save this image as a new file"),image_save_as,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS,
-	0,0,NULL
-     },
+   GNOMEUIINFO_ITEM_STOCK(N_("Open"),N_("Open up a new image file and add it to the image list"),image_open, 
+			  GNOME_STOCK_MENU_OPEN),
+   GNOMEUIINFO_ITEM_STOCK(N_("Save"),N_("Save this image"),image_save,GNOME_STOCK_MENU_SAVE),
+   GNOMEUIINFO_ITEM_STOCK(N_("Save As"),N_("Save this image as a new file"),image_save_as,GNOME_STOCK_MENU_SAVE_AS),
    GNOMEUIINFO_SEPARATOR,
-     { GNOME_APP_UI_ITEM,N_("Next Image"),N_("Display the next image in the image list"),handle_image_next,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD,
-	0,0,NULL
-     },
-     { GNOME_APP_UI_ITEM,N_("Previous Image"),N_("Display the previous image in the image list"),handle_image_previous,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK,
-	0,0,NULL
-     },
-     { GNOME_APP_UI_ITEM,N_("Start Slideshow"),N_("Start an automated slideshow of all the images in the image list"),start_slideshow,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
-	0,0,NULL
-     },
-     { GNOME_APP_UI_ITEM,N_("Stop Slideshow"),N_("Start an automated slideshow of all the images in the image list"),stop_slideshow,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
-	0,0,NULL
-     },
+   GNOMEUIINFO_ITEM_STOCK(N_("Next Image"),N_("Display the next image in the image list"),handle_image_next, 
+			  GNOME_STOCK_MENU_FORWARD),
+   GNOMEUIINFO_ITEM_STOCK(N_("Previous Image"),N_("Display the previous image in the image list"),handle_image_previous,
+			  GNOME_STOCK_MENU_BACK),
+   GNOMEUIINFO_ITEM_STOCK(N_("Start Slideshow"),N_("Start an automated slideshow of all the images in the image list"),
+			  start_slideshow,GNOME_STOCK_MENU_ABOUT),
+   GNOMEUIINFO_ITEM_STOCK(N_("Stop Slideshow"),N_("Start an automated slideshow of all the images in the image list"),
+			  stop_slideshow,GNOME_STOCK_MENU_ABOUT),
    GNOMEUIINFO_SEPARATOR,
-   GNOMEUIINFO_ITEM(N_("Print"),N_("Print this Image"),print_image,NULL),
+   GNOMEUIINFO_ITEM_STOCK(N_("Print"),N_("Print this Image"),print_image,GNOME_STOCK_MENU_BLANK),
    GNOMEUIINFO_SEPARATOR,
-     { GNOME_APP_UI_ITEM,N_("Quit"),N_("Exit this program"),quit_image_cb,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
-	0,0,NULL
-     },
+   GNOMEUIINFO_ITEM_STOCK(N_("Quit"),N_("Exit this program"),quit_image_cb, GNOME_STOCK_MENU_QUIT),
    GNOMEUIINFO_END
 };
 
@@ -75,25 +64,12 @@ static GnomeUIInfo menu2[]=
    GNOMEUIINFO_SUBTREE(N_("Edit"),menu4),
    GNOMEUIINFO_SUBTREE(N_("Image"),menu5),
    GNOMEUIINFO_SEPARATOR,
-     { GNOME_APP_UI_ITEM,N_("Preferences"),N_("Change your user preferences for this program"),show_config,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
-	0,0,NULL
-     },
-   GNOMEUIINFO_HELP("ElectricEyes"),
-     { GNOME_APP_UI_ITEM,N_("About"),N_("Info about this program"),about_image_cb,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
-	0,0,NULL
-     },
-   GNOMEUIINFO_HELP("ElectricEyes"),
-     { GNOME_APP_UI_ITEM,N_("Help"),N_("Help on this program"),about_image_help_cb,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
-	0,0,NULL
-     },
+   GNOMEUIINFO_ITEM_STOCK(N_("Preferences"), N_("Change your user preferences for this program"), show_config, 
+			  GNOME_STOCK_MENU_PREF),
+   
+   GNOMEUIINFO_SUBTREE(N_("Help"), menu6),
    GNOMEUIINFO_SEPARATOR,
-     { GNOME_APP_UI_ITEM,N_("Quit"),N_("Exit this program"),quit_image_cb,NULL,
-	NULL,GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
-	0,0,NULL
-     },
+   GNOMEUIINFO_ITEM_STOCK(N_("Quit"),N_("Exit this program"),quit_image_cb, GNOME_STOCK_MENU_QUIT),
    GNOMEUIINFO_END
 };
 
@@ -318,6 +294,23 @@ void handle_image_resize_down(GtkWidget *widget, GdkEventConfigure *event)
 void handle_image_resize_original(GtkWidget *widget, GdkEventConfigure *event)
 {
    if (!current.image) return;
+
+#ifdef 1
+   gtk_spin_button_spin(GTK_SPIN_BUTTON(height_wid),GTK_SPIN_USER_DEFINED,(gfloat)
+			(current.image->rgb_height - 
+			 gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height_wid))));
+   gtk_spin_button_spin(GTK_SPIN_BUTTON(width_wid),GTK_SPIN_USER_DEFINED,(gfloat)
+			(current.image->rgb_width - 
+			 gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width_wid))));   
+#else
+   gtk_spin_button_spin(GTK_SPIN_BUTTON(height_wid),0,(gfloat)
+			(current.image->rgb_height - 
+			 gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height_wid))));
+   gtk_spin_button_spin(GTK_SPIN_BUTTON(width_wid),0,(gfloat)
+			(current.image->rgb_width - 
+			 gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width_wid))));
+#endif
+
    gtk_widget_set_usize(window_image,current.image->rgb_width,current.image->rgb_height);
 }
 
